// Translation system for Tuan Master website
import { supabase } from "@/integrations/supabase/client";

export type Language = 'EN' | 'CZ' | 'VI';

export interface Translations {
  // Header
  header: {
    bookConsultation: string;
    navigation: {
      home: string;
      portfolio: string;
      packages: string;
      testimonials: string;
      about: string;
      contact: string;
    };
  };

  // Hero Section
  hero: {
    title: string;
    subtitle: string;
    description: string;
    cta: string;
  };

  // About Section
  about: {
    title: string;
    philosophy: string;
    description: string;
  };

  // Services/Packages Section
  services: {
    title: string;
    subtitle: string;
    description: string;
    mostPopular: string;
    singleVideographer: string;
    dualVideographers: string;
    discoverLuxury: string;
    limitedBonus: string;
    bonusTitle: string;
    bonusDescription: string;
    bonusNote: string;
    bottomNote: string;
    beyond: string;
    beyondSubtitle: string;
    chooseEssential: string;
    choosePremium: string;
    
    // Package names and descriptions - names stay in English
    essential: {
      name: string; // Always "Essential"
      title: string;
      description: string;
      workingHours: string;
      overtimeNote: string;
    };
    premium: {
      name: string; // Always "Premium"
      title: string;
      description: string;
      workingHours: string;
      overtimeNote: string;
    };
    luxury: {
      name: string; // Always "Luxury Experience"
      title: string;
      description: string;
      workingHours: string;
      timeRange: string;
    };
    
    // Package features translations
    features: {
      highlightReel: string;
      fullCeremonyFilm: string;
      usbPackage: string;
      musicSoundtrack: string;
      consultation: string;
      extendedCoverage: string;
      sneakPeek: string;
      cinematicHighlight: string;
      premiumUsb: string;
      extensiveConsultation: string;
      fullDayCoverage: string;
      socialTeasers: string;
      premiumEditing: string;
      droneFootage: string;
      secondShooter: string;
      rawFootage: string;
      prioritySupport: string;
    };
  };

  // Contact Section
  contact: {
    title: string;
    subtitle: string;
    basedIn: string;
    travelNote: string;
    form: {
      yourName: string;
      partnerName: string;
      sessionType: string;
      chooseSessionType: string;
      dateLabel: string;
      pickDate: string;
      email: string;
      phone: string;
      location: string;
      message: string;
      messagePlaceholder: string;
      sendMessage: string;
      sessionTypes: {
        wedding: string;
        engagement: string;
        portrait: string;
        family: string;
        elopement: string;
        rehearsal: string;
        ceremony: string;
      };
    };
  };

  // Testimonials Section
  testimonials: {
    title: string;
  };

  // Partners Section
  partners: {
    title: string;
    subtitle: string;
    description: string;
  };

  // Offerings Section
  offerings: {
    title: string;
    services: {
      wedding: string;
      portraits: string;
      editorial: string;
      brands: string;
    };
  };

  // Footer
  footer: {
    explore: string;
    learn: string;
    connect: string;
    stories: string;
    albums: string;
    venues: string;
    faq: string;
    tips: string;
    pricing: string;
    contact: string;
    about: string;
    socialMedia: string;
    copyright: string;
  };

  // Instagram Gallery
  instagram: {
    scrollText: string;
  };

  // Blog Section
  blog: {
    viewAllStories: string;
  };

  // Common
  common: {
    prague: string;
    czechRepublic: string;
  };
}

// Package definitions with multi-language support
export const packageDefinitions = {
  essential: {
    CZ: {
      name: "Essential",
      title: "Essential Package",
      description: "Základní balíček pro vaši svatbu",
      workingHours: "Do 8 hodin natáčení",
      overtimeNote: "Přesčasy účtovány extra",
      features: [
        "Highlight reel (3-5 min)",
        "Kompletní obřad",
        "USB v elegantní krabičce",
        "Hudební podklad",
        "Předsvatební konzultace"
      ]
    },
    EN: {
      name: "Essential",
      title: "Essential Package",
      description: "Basic package for your wedding",
      workingHours: "Up to 8 hours filming",
      overtimeNote: "Overtime charged extra",
      features: [
        "Highlight reel (3-5 min)",
        "Full ceremony film",
        "USB in elegant box",
        "Music soundtrack",
        "Pre-wedding consultation"
      ]
    },
    VN: {
      name: "Essential",
      title: "Gói Essential",
      description: "Gói cơ bản cho đám cưới của bạn",
      workingHours: "Quay phim tối đa 8 giờ",
      overtimeNote: "Tính phí thêm giờ",
      features: [
        "Video tóm tắt (3-5 phút)",
        "Phim lễ cưới đầy đủ",
        "USB trong hộp sang trọng",
        "Nhạc nền",
        "Tư vấn trước cưới"
      ]
    }
  },
  premium: {
    CZ: {
      name: "Premium",
      title: "Premium Package",
      description: "Rozšířený balíček s více službami",
      workingHours: "Do 10 hodin natáčení",
      overtimeNote: "Přesčasy účtovány extra",
      features: [
        "Highlight reel (3-5 min)",
        "Kompletní obřad",
        "USB v elegantní krabičce",
        "Hudební podklad",
        "Předsvatební konzultace",
        "Rozšířené pokrytí",
        "Sneak peek video"
      ]
    },
    EN: {
      name: "Premium",
      title: "Premium Package",
      description: "Extended package with more services",
      workingHours: "Up to 10 hours filming",
      overtimeNote: "Overtime charged extra",
      features: [
        "Highlight reel (3-5 min)",
        "Full ceremony film",
        "USB in elegant box",
        "Music soundtrack",
        "Pre-wedding consultation",
        "Extended coverage",
        "Sneak peek video"
      ]
    },
    VN: {
      name: "Premium",
      title: "Gói Premium",
      description: "Gói mở rộng với nhiều dịch vụ hơn",
      workingHours: "Quay phim tối đa 10 giờ",
      overtimeNote: "Tính phí thêm giờ",
      features: [
        "Video tóm tắt (3-5 phút)",
        "Phim lễ cưới đầy đủ",
        "USB trong hộp sang trọng",
        "Nhạc nền",
        "Tư vấn trước cưới",
        "Phạm vi quay rộng",
        "Video xem trước"
      ]
    }
  },
  luxury: {
    CZ: {
      name: "Beyond Extraordinary",
      title: "Luxury Experience",
      description: "Prémiový zážitek s kompletní službou",
      workingHours: "Celý den natáčení",
      timeRange: "12+ hodin",
      features: [
        "Kinematografický highlight reel",
        "Kompletní obřad",
        "Prémiové USB v dřevěné krabičce",
        "Hudební podklad",
        "Rozsáhlá konzultace",
        "Celý den pokrytí",
        "Sociální média teasery",
        "Prémiová editace",
        "Drone záběry",
        "Druhý kameraman",
        "Surové záběry",
        "Prioritní podpora"
      ]
    },
    EN: {
      name: "Beyond Extraordinary",
      title: "Luxury Experience",
      description: "Premium experience with complete service",
      workingHours: "Full day filming",
      timeRange: "12+ hours",
      features: [
        "Cinematic highlight reel",
        "Full ceremony film",
        "Premium USB in wooden box",
        "Music soundtrack",
        "Extensive consultation",
        "Full day coverage",
        "Social media teasers",
        "Premium editing",
        "Drone footage",
        "Second shooter",
        "Raw footage",
        "Priority support"
      ]
    },
    VN: {
      name: "Beyond Extraordinary",
      title: "Trải nghiệm Luxury",
      description: "Trải nghiệm cao cấp với dịch vụ hoàn chỉnh",
      workingHours: "Quay phim cả ngày",
      timeRange: "12+ giờ",
      features: [
        "Video highlight điện ảnh",
        "Phim lễ cưới đầy đủ",
        "USB cao cấp trong hộp gỗ",
        "Nhạc nền",
        "Tư vấn toàn diện",
        "Quay phim cả ngày",
        "Video teaser mạng xã hội",
        "Chỉnh sửa cao cấp",
        "Quay flycam",
        "Quay phim thứ hai",
        "Video thô",
        "Hỗ trợ ưu tiên"
      ]
    }
  }
} as const;

// Contract management translations
export const contractTranslations = {
  CZ: {
    // Navigation
    nav: {
      home: 'Domů',
      about: 'O nás',
      services: 'Služby',
      portfolio: 'Portfolio',
      blog: 'Blog',
      contact: 'Kontakt',
      admin: 'Administrace'
    },
    
    // Contract management
    contracts: {
      title: 'Správa smluv',
      new: 'Nová smlouva',
      edit: 'Upravit smlouvu',
      delete: 'Smazat smlouvu',
      view: 'Zobrazit smlouvu',
      list: 'Seznam smluv',
      contractNumber: 'Číslo smlouvy',
      
      // Client information
      clientInfo: 'Informace o klientovi',
      clientName: 'Jméno zákazníka',
      clientEmail: 'E-mail zákazníka',
      clientPhone: 'Telefon zákazníka',
      
      // Wedding details
      weddingDetails: 'Detaily svatby',
      weddingDate: 'Datum svatby',
      weddingVenue: 'Místo svatby',
      weddingAddress: 'Adresa svatby',
      
      // Package selection
      packageSelection: 'Výběr balíčku',
      packageType: 'Typ balíčku',
      packageDetails: 'Detaily balíčku',
      packageFeatures: 'Zahrnuje',
      language: 'Jazyk smlouvy',
      currency: 'Měna',
      packageColumn: 'Balíček',
      selectPackage: 'Vyberte balíček',
      
      // Financial information
      financialInfo: 'Finanční informace',
      totalPrice: 'Celková cena',
      depositPaid: 'Zaplacená záloha',
      remainingAmount: 'Zbývající částka',
      paymentDueDate: 'Datum doplacení',
      
      // Service details
      serviceDetails: 'Detaily služby',
      clientRequirements: 'Požadavky klienta',
      clientRequirementsPlaceholder: 'Speciální požadavky klienta, důležité momenty k zachycení...',
      includedGifts: 'Dárky zahrnuté ve službě',
      deliveryTimeline: 'Termín dodání',
      
      // Status
      status: 'Stav',
      statusDraft: 'Koncept',
      statusActive: 'Aktivní',
      statusCompleted: 'Dokončeno',
      statusCancelled: 'Zrušeno',
      
      // Media
      media: 'Média',
      addMedia: 'Přidat média',
      mediaTitle: 'Název média',
      mediaDescription: 'Popis média',
      mediaType: 'Typ média',
      mediaUrl: 'URL média',
      downloadUrl: 'URL pro stažení',
      
      mediaTypes: {
        short_video: 'Krátké video (3-5 min)',
        long_video: 'Dlouhé video (7-15 min)',
        reels: 'Reels (1-3 klipy)',
        photos: 'Fotografie',
        other: 'Ostatní'
      },
      
      // Actions
      save: 'Uložit',
      cancel: 'Zrušit',
      deleteAction: 'Smazat',
      editAction: 'Upravit',
      download: 'Stáhnout',
      share: 'Sdílet',
      
      // Messages
      saveSuccess: 'Smlouva byla úspěšně uložena',
      deleteSuccess: 'Smlouva byla úspěšně smazána',
      saveError: 'Chyba při ukládání smlouvy',
      deleteError: 'Chyba při mazání smlouvy',
      fullySignedTitle: 'Smlouva je podepsána oběma stranami',
      fullySignedMessage: 'Tato smlouva je již podepsána oběma stranami a nemůže být upravována. Jakékoli změny musí být provedeny prostřednictvím dodatků ke smlouvě.'
    },
    
    // Public contract view
    publicContract: {
      title: 'Smlouva o dílo',
      contractDetails: 'Detaily smlouvy',
      paymentInfo: 'Informace o platbě',
      weddingInfo: 'Informace o svatbě',
      mediaDownloads: 'Ke stažení',
      noMediaYet: 'Média zatím nejsou k dispozici',
      mediaWillBeAvailable: 'Vaše videa a fotografie budou k dispozici dle termínu dodání uvedeného ve smlouvě.',
      
      // Header
      contractNotFound: 'Smlouva nenalezena',
      invalidLink: 'Zadaný odkaz není platný nebo smlouva neexistuje.',
      printPdf: 'Tisknout PDF',
      
      // Contract document
      contractTitle: 'SMLOUVA O POSKYTOVÁNÍ SVATEBNÍ SLUŽBY',
      contractSubtitle: 'podle § 2586 a násl. zákona č. 89/2012 Sb., občanský zákoník',
      
      // Company info
      companyName: 'Tuanmaster',
      companyAddress: 'Libušská 319/126, 14200 Praha',
      companyPhone: '+420 778 514 888',
      companyEmail: 'info@tuanmaster.eu',
      companyIco: 'IČO: 28578996',
      companyBank: 'Bankovní spojení: 348018965/0300',
      
      // Parties
      contractor: 'Zhotovitel',
      client: 'Objednatel',
      contractorSide: '(dále jen jako „Zhotovitel" na straně jedné)',
      clientSide: '(dále jen jako „Objednatel" na straně druhé)',
      contractAgreement: 'uzavírají smlouvu o dílo.',
      
      // Client details
      clientLabel: 'Klient:',
      venueLabel: 'Místo konání:',
      dateLabel: 'Datum konání:',
      phoneLabel: 'Tel:',
      emailLabel: 'E-mail:',
      
      // Contract sections
      generalTerms: 'VŠEOBECNÉ OBCHODNÍ PODMÍNKY',
      generalTermsText1: 'Všeobecné obchodní podmínky (dále jen „VOP") se vztahují na všechny smlouvy o dílo na vyhotovení videových děl, poskytnutí videových služeb a potvrzení objednávek živnostníkem Bui Van Yen, se sídlem Libušská 319/126, 14200 Praha, IČO: 28578996 (dále jen „zhotovitel")',
      generalTermsText2: 'Při uzavírání smlouvy se vychází ze skutečnosti, že objednatel je seznámen s těmito VOP a dalšími níže popsanými dokumenty.',
      
      pricingTerms: 'CENA PŘEDMĚTU PLNĚNÍ, DOBA PLATNOSTI CENY A ZPŮSOB PLATBY CENY',
      pricingText1: 'Smluvní strany se dohodly, že celková cena díla bude činit částkou ve výši',
      pricingText2: 'a bude uhrazena na výše uvedený bankovní účet následovně:',
      pricingText3: '1. Rezervační poplatek (Záloha) 40 % ze celkové částky po podepsání smlouvy',
      pricingText4: '2. Doplatek zbylé částky po domluvě (před či po svatební hostině v hotovosti, nebo 1-3 dny po svatební hostině na výše uvedený bank.účet.',
      pricingText5: 'Rezervační poplatek (záloha) je nevratný.',
      
      cancellationTerms: 'PODMÍNKY ZRUŠENÍ SMLOUVY',
      cancellationText1: 'Pokud Objednatel svévolně zruší nebo ukončí smlouvu z nějakých důvodů – jako je změna kameramana nebo změna data, kdy kameraman se nemůže dohodnout na harmonogramu, Objednatel ztratí zálohu.',
      cancellationText2: 'Pokud je zrušení z přijatelného důvodu, záloha bude rezervována pro jiný domluvený termín nebo další osobu (lze ji převést na přátelé, členy z rodiny, atd. - platnost 1 rok)',
      
      contractorRights: 'PRÁVA A POVINNOSTI ZHOTOVITELE',
      contractorText1: 'Není-li dohodnuto jinak, zhotovitel provede dílo v kvalitě obvyklé v ČR a dodá:',
      contractorText2: 'Smluvní strany se dohodly, že dílo bude Zhotovitelem zhotoveno a předáno v rozmezí',
      contractorText3: 'ode dne svatební hostiny. Doba zpracování videí může být prodloužena, objednatel bude upozorněn.',
      contractorText4: 'Po dohodě se zákazníkem má zhotovitel právo využívat upravené videa pro svou webovou prezentaci (soc.sítě - FB, IG a jiné) či tiskoviny jako ukázku své práce, či pro účely propagace svých služeb.',
      contractorText5: 'Zhotovitel se zavazuje zákazníkovi zhotovit a dodat objednanou zakázku v množství a kvalitě dohodnuté ve této smlouvě.',
      contractorText6: 'Hotový produkt bude uchováván pro Objednatele po dobu 1 roku. V případě ztráty si jej může objednatel vyžádat zpět. Po uplynutí 1 roku nenese Zhotovitel za produkt odpovědnost (bude účtován poplatek za USB + poštovné).',
      
      clientRights: 'PRÁVA A POVINNOSTI OBJEDNATELE',
      clientText1: 'Objednatel má právo požádat zhotovitele o odstranění videa z soc.sítích v případě, že je zákazník odmítá z osobních situacích. Zhotovitel se zavazuje takovému přání vyhovět do co možná nejkratší doby od obdržení žádosti.',
      clientText2: 'Svůj termín si může objednatel změnit z důvodu počasí nebo z osobních důvodů, pokud v novém termínu má Zhotovitel volno.',
      clientText3: 'Objednatel má právo požádat zhotovitele o úpravu videí 1 – 3x',
      clientSpecialRequirements: 'Zvláštní požadavky objednatele:',
      
      changesExceptions: '*ZMĚNY A VYJÍMKY',
      changesText: 'Objednatel je oprávněn v případě vyšší moci (zejména nařízení orgánů veřejné správy ČR omezující průběh svatebního dne) přesunout datum konání akcí na nový termín ve stejném roce bez žádného poplatku.',
      
      warrantyTerms: 'ZÁRUČNÍ DOBA, PRÁVA Z ODPOVĚDNOSTI ZA VADY',
      warrantyText: 'Za vady informuje Objednatel Zhotoviteli neprodleně po jejich zjištění, nejdéle však do 30 dnů ode dne převzetí zakázky, tj. v záruční době.',
      
      finalProvisions: 'ZÁVĚREČNÁ USTANOVENÍ',
      finalProvisionsText: 'Podepsáním této smlouvy a uhrazením zálohy zákazník současně potvrzuje, že se seznámil s těmito VOP, platnou cenovou nabídkou zhotovitele, včetně podmínek kvality díla a lhůt plnění a tyto přijímá.',
      
      contractLocation: 'V Praze dne',
      contractMonth: 'měsíc',
      contractYear: 'rok',
      
      // Package info
      packageLabel: 'Balíček:',
      workingHours: 'Pracovní doba:',
      deliverables: 'Dodávky:',
      
      // Signature section
      signatureSection: 'PODPISY',
      contractorSignature: 'Podpis zhotovitele:',
      clientSignature: 'Podpis objednatele:',
      date: 'Datum:',
      signedBy: 'Podepsáno:',
      signatureDate: 'Datum podpisu:',
      signContract: 'Podepsat smlouvu',
      confirmSignature: 'Potvrdit podpis',
      signatureConfirmation: 'Potvrďte, že chcete podepsat smlouvu.',
      signatureSuccess: 'Smlouva byla úspěšně podepsána',
      signatureError: 'Nepodařilo se podepsat smlouvu. Zkuste to prosím znovu.',
      
      // Amendment section
      amendments: 'PŘÍLOHY KE SMLOUVĚ',
      
      // Toast messages
      toastError: 'Chyba',
      toastSuccess: 'Úspěch',
      toastLinkCopied: 'Odkaz byl zkopírován do schránky',
      toastDataLoadError: 'Nepodařilo se načíst data smlouvy',
      
      // Payment status
      totalAmount: 'Celková částka',
      paidDeposit: 'Zaplacená záloha',
      remainingPayment: 'Zbývá k doplacení',
      paymentDue: 'Datum doplacení',
      
      // Wedding info
      venue: 'Místo',
      address: 'Adresa',
      requirements: 'Speciální požadavky',
      gifts: 'Dárky zahrnuté',
      delivery: 'Termín dodání'
    },
    
    // Common
    common: {
      loading: 'Načítání...',
      error: 'Chyba',
      success: 'Úspěch',
      yes: 'Ano',
      no: 'Ne',
      close: 'Zavřít',
      back: 'Zpět'
    }
  },
  
  EN: {
    // Navigation
    nav: {
      home: 'Home',
      about: 'About',
      services: 'Services',
      portfolio: 'Portfolio',
      blog: 'Blog',
      contact: 'Contact',
      admin: 'Administration'
    },
    
    // Contract management
    contracts: {
      title: 'Contract Management',
      new: 'New Contract',
      edit: 'Edit Contract',
      delete: 'Delete Contract',
      view: 'View Contract',
      list: 'Contract List',
      contractNumber: 'Contract Number',
      
      // Client information
      clientInfo: 'Client Information',
      clientName: 'Client Name',
      clientEmail: 'Client Email',
      clientPhone: 'Client Phone',
      
      // Wedding details
      weddingDetails: 'Wedding Details',
      weddingDate: 'Wedding Date',
      weddingVenue: 'Wedding Venue',
      weddingAddress: 'Wedding Address',
      
      // Package selection
      packageSelection: 'Package Selection',
      packageType: 'Package Type',
      packageDetails: 'Package Details',
      packageFeatures: 'Includes',
      language: 'Contract Language',
      currency: 'Currency',
      packageColumn: 'Package',
      selectPackage: 'Select Package',
      
      // Financial information
      financialInfo: 'Financial Information',
      totalPrice: 'Total Price',
      depositPaid: 'Deposit Paid',
      remainingAmount: 'Remaining Amount',
      paymentDueDate: 'Payment Due Date',
      
      // Service details
      serviceDetails: 'Service Details',
      clientRequirements: 'Client Requirements',
      clientRequirementsPlaceholder: 'Special client requirements, important moments to capture...',
      includedGifts: 'Included Gifts',
      deliveryTimeline: 'Delivery Timeline',
      
      // Status
      status: 'Status',
      statusDraft: 'Draft',
      statusActive: 'Active',
      statusCompleted: 'Completed',
      statusCancelled: 'Cancelled',
      
      // Media
      media: 'Media',
      addMedia: 'Add Media',
      mediaTitle: 'Media Title',
      mediaDescription: 'Media Description',
      mediaType: 'Media Type',
      mediaUrl: 'Media URL',
      downloadUrl: 'Download URL',
      
      mediaTypes: {
        short_video: 'Short video (3-5 min)',
        long_video: 'Long video (7-15 min)',
        reels: 'Reels (1-3 clips)',
        photos: 'Photos',
        other: 'Other'
      },
      
      // Actions
      save: 'Save',
      cancel: 'Cancel',
      deleteAction: 'Delete',
      editAction: 'Edit',
      download: 'Download',
      share: 'Share',
      
      // Messages
      saveSuccess: 'Contract saved successfully',
      deleteSuccess: 'Contract deleted successfully',
      saveError: 'Error saving contract',
      deleteError: 'Error deleting contract',
      fullySignedTitle: 'Contract is signed by both parties',
      fullySignedMessage: 'This contract is already signed by both parties and cannot be edited. Any changes must be made through contract amendments.'
    },
    
    // Public contract view
    publicContract: {
      title: 'Service Contract',
      contractDetails: 'Contract Details',
      paymentInfo: 'Payment Information',
      weddingInfo: 'Wedding Information',
      mediaDownloads: 'Downloads',
      noMediaYet: 'Media not yet available',
      mediaWillBeAvailable: 'Your videos and photos will be available according to the delivery timeline specified in the contract.',
      
      // Header
      contractNotFound: 'Contract not found',
      invalidLink: 'The provided link is invalid or the contract does not exist.',
      printPdf: 'Print PDF',
      
      // Contract document
      contractTitle: 'WEDDING SERVICE CONTRACT',
      contractSubtitle: 'according to § 2586 et seq. of Act No. 89/2012 Coll., Civil Code',
      
      // Company info
      companyName: 'Tuanmaster',
      companyAddress: 'Libušská 319/126, 14200 Prague',
      companyPhone: '+420 778 514 888',
      companyEmail: 'info@tuanmaster.eu',
      companyIco: 'Business ID: 28578996',
      companyBank: 'Bank account: 348018965/0300',
      
      // Parties
      contractor: 'Contractor',
      client: 'Client',
      contractorSide: '(hereinafter referred to as "Contractor" on one side)',
      clientSide: '(hereinafter referred to as "Client" on the other side)',
      contractAgreement: 'conclude a service contract.',
      
      // Client details
      clientLabel: 'Client:',
      venueLabel: 'Venue:',
      dateLabel: 'Date:',
      phoneLabel: 'Phone:',
      emailLabel: 'Email:',
      
      // Contract sections
      generalTerms: 'GENERAL TERMS AND CONDITIONS',
      generalTermsText1: 'General Terms and Conditions (hereinafter referred to as "GTC") apply to all service contracts for video production, video services and order confirmations by entrepreneur Bui Van Yen, with registered address Libušská 319/126, 14200 Prague, Business ID: 28578996 (hereinafter referred to as "contractor")',
      generalTermsText2: 'When concluding the contract, it is assumed that the client is familiar with these GTC and other documents described below.',
      
      pricingTerms: 'PRICE OF SUBJECT MATTER, PRICE VALIDITY PERIOD AND PAYMENT METHOD',
      pricingText1: 'The contracting parties have agreed that the total price of the work will amount to',
      pricingText2: 'and will be paid to the above-mentioned bank account as follows:',
      pricingText3: '1. Booking fee (Deposit) 40% of the total amount after signing the contract',
      pricingText4: '2. Balance payment by agreement (before or after the wedding reception in cash, or 1-3 days after the wedding reception to the above-mentioned bank account.',
      pricingText5: 'The booking fee (deposit) is non-refundable.',
      
      cancellationTerms: 'CONTRACT CANCELLATION CONDITIONS',
      cancellationText1: 'If the Client voluntarily cancels or terminates the contract for any reason - such as changing the videographer or changing the date when the videographer cannot agree on the schedule, the Client will lose the deposit.',
      cancellationText2: 'If the cancellation is for an acceptable reason, the deposit will be reserved for another agreed date or another person (can be transferred to friends, family members, etc. - validity 1 year)',
      
      contractorRights: 'RIGHTS AND OBLIGATIONS OF THE CONTRACTOR',
      contractorText1: 'Unless otherwise agreed, the contractor will perform the work in the quality usual in the Czech Republic and deliver:',
      contractorText2: 'The contracting parties have agreed that the work will be completed and delivered by the Contractor within',
      contractorText3: 'from the day of the wedding reception. Video processing time may be extended, the client will be notified.',
      contractorText4: 'By agreement with the customer, the contractor has the right to use edited videos for their web presentation (social networks - FB, IG and others) or printed materials as a sample of their work, or for promotional purposes of their services.',
      contractorText5: 'The contractor undertakes to complete and deliver the ordered work in the quantity and quality agreed in this contract.',
      contractorText6: 'The finished product will be stored for the Client for 1 year. In case of loss, the client can request it back. After 1 year, the Contractor is not responsible for the product (a fee for USB + postage will be charged).',
      
      clientRights: 'RIGHTS AND OBLIGATIONS OF THE CLIENT',
      clientText1: 'The Client has the right to ask the contractor to remove the video from social networks in case the customer refuses them for personal reasons. The contractor undertakes to comply with such a request as soon as possible after receiving the request.',
      clientText2: 'The client can change their date due to weather or personal reasons, if the Contractor is available on the new date.',
      clientText3: 'The Client has the right to ask the contractor to edit videos 1-3 times',
      clientSpecialRequirements: 'Special client requirements:',
      
      changesExceptions: '*CHANGES AND EXCEPTIONS',
      changesText: 'The Client is entitled in case of force majeure (especially orders from Czech public administration authorities limiting the course of the wedding day) to move the date of the event to a new date in the same year without any fee.',
      
      // Package info
      packageLabel: 'Package:',
      workingHours: 'Working hours:',
      deliverables: 'Deliverables:',
      
      // Signature section
      signatureSection: 'SIGNATURES',
      contractorSignature: 'Contractor signature:',
      clientSignature: 'Client signature:',
      date: 'Date:',
      signedBy: 'Signed by:',
      signatureDate: 'Signature date:',
      signContract: 'Sign Contract',
      confirmSignature: 'Confirm Signature',
      signatureConfirmation: 'Confirm that you want to sign the contract.',
      signatureSuccess: 'Contract signed successfully',
      signatureError: 'Failed to sign contract. Please try again.',
      
      // Amendment section
      amendments: 'CONTRACT AMENDMENTS',
      
      // Toast messages
      toastError: 'Error',
      toastSuccess: 'Success',
      toastLinkCopied: 'Link copied to clipboard',
      toastDataLoadError: 'Failed to load contract data',
      
      // Payment status
      totalAmount: 'Total Amount',
      paidDeposit: 'Paid Deposit',
      remainingPayment: 'Remaining Payment',
      paymentDue: 'Payment Due Date',
      
      // Wedding info
      venue: 'Venue',
      address: 'Address',
      requirements: 'Special Requirements',
      gifts: 'Included Gifts',
      delivery: 'Delivery Timeline'
    },
    
    // Common
    common: {
      loading: 'Loading...',
      error: 'Error',
      success: 'Success',
      yes: 'Yes',
      no: 'No',
      close: 'Close',
      back: 'Back'
    }
  },
  
  VN: {
    // Navigation
    nav: {
      home: 'Trang chủ',
      about: 'Giới thiệu',
      services: 'Dịch vụ',
      portfolio: 'Portfolio',
      blog: 'Blog',
      contact: 'Liên hệ',
      admin: 'Quản trị'
    },
    
    // Contract management
    contracts: {
      title: 'Quản lý hợp đồng',
      new: 'Hợp đồng mới',
      edit: 'Chỉnh sửa hợp đồng',
      delete: 'Xóa hợp đồng',
      view: 'Xem hợp đồng',
      list: 'Danh sách hợp đồng',
      contractNumber: 'Số hợp đồng',
      
      // Client information
      clientInfo: 'Thông tin khách hàng',
      clientName: 'Tên khách hàng',
      clientEmail: 'Email khách hàng',
      clientPhone: 'Số điện thoại khách hàng',
      
      // Wedding details
      weddingDetails: 'Chi tiết đám cưới',
      weddingDate: 'Ngày cưới',
      weddingVenue: 'Địa điểm cưới',
      weddingAddress: 'Địa chỉ cưới',
      
      // Package selection
      packageSelection: 'Lựa chọn gói',
      packageType: 'Loại gói',
      packageDetails: 'Chi tiết gói',
      packageFeatures: 'Bao gồm',
      language: 'Ngôn ngữ hợp đồng',
      currency: 'Tiền tệ',
      packageColumn: 'Gói',
      selectPackage: 'Chọn gói',
      
      // Financial information
      financialInfo: 'Thông tin tài chính',
      totalPrice: 'Tổng giá',
      depositPaid: 'Tiền cọc đã trả',
      remainingAmount: 'Số tiền còn lại',
      paymentDueDate: 'Ngày thanh toán',
      
      // Service details
      serviceDetails: 'Chi tiết dịch vụ',
      clientRequirements: 'Yêu cầu khách hàng',
      clientRequirementsPlaceholder: 'Yêu cầu đặc biệt của khách hàng, những khoảnh khắc quan trọng cần ghi lại...',
      includedGifts: 'Quà tặng kèm theo',
      deliveryTimeline: 'Thời gian giao hàng',
      
      // Status
      status: 'Trạng thái',
      statusDraft: 'Bản nháp',
      statusActive: 'Hoạt động',
      statusCompleted: 'Hoàn thành',
      statusCancelled: 'Đã hủy',
      
      // Media
      media: 'Phương tiện',
      addMedia: 'Thêm phương tiện',
      mediaTitle: 'Tiêu đề phương tiện',
      mediaDescription: 'Mô tả phương tiện',
      mediaType: 'Loại phương tiện',
      mediaUrl: 'URL phương tiện',
      downloadUrl: 'URL tải xuống',
      
      mediaTypes: {
        short_video: 'Video ngắn (3-5 phút)',
        long_video: 'Video dài (7-15 phút)',
        reels: 'Reels (1-3 clip)',
        photos: 'Hình ảnh',
        other: 'Khác'
      },
      
      // Actions
      save: 'Lưu',
      cancel: 'Hủy',
      deleteAction: 'Xóa',
      editAction: 'Chỉnh sửa',
      download: 'Tải xuống',
      share: 'Chia sẻ',
      
      // Messages
      saveSuccess: 'Hợp đồng đã được lưu thành công',
      deleteSuccess: 'Hợp đồng đã được xóa thành công',
      saveError: 'Lỗi khi lưu hợp đồng',
      deleteError: 'Lỗi khi xóa hợp đồng',
      fullySignedTitle: 'Hợp đồng đã được ký bởi cả hai bên',
      fullySignedMessage: 'Hợp đồng này đã được ký bởi cả hai bên và không thể chỉnh sửa. Mọi thay đổi phải được thực hiện thông qua phụ lục hợp đồng.'
    },
    
    // Public contract view
    publicContract: {
      title: 'Hợp đồng dịch vụ',
      contractDetails: 'Chi tiết hợp đồng',
      paymentInfo: 'Thông tin thanh toán',
      weddingInfo: 'Thông tin đám cưới',
      mediaDownloads: 'Tải xuống',
      noMediaYet: 'Chưa có phương tiện nào',
      mediaWillBeAvailable: 'Video và hình ảnh của bạn sẽ có sẵn theo thời gian giao hàng được chỉ định trong hợp đồng.',
      
      // Header
      contractNotFound: 'Không tìm thấy hợp đồng',
      invalidLink: 'Liên kết được cung cấp không hợp lệ hoặc hợp đồng không tồn tại.',
      printPdf: 'In PDF',
      
      // Contract document
      contractTitle: 'HỢP ĐỒNG DỊCH VỤ CƯỚI',
      contractSubtitle: 'theo § 2586 và các điều tiếp theo của Luật số 89/2012 Sb., Bộ luật Dân sự',
      
      // Company info
      companyName: 'Tuanmaster',
      companyAddress: 'Libušská 319/126, 14200 Prague',
      companyPhone: '+420 778 514 888',
      companyEmail: 'info@tuanmaster.eu',
      companyIco: 'Mã số doanh nghiệp: 28578996',
      companyBank: 'Tài khoản ngân hàng: 348018965/0300',
      
      // Parties
      contractor: 'Nhà thầu',
      client: 'Khách hàng',
      contractorSide: '(sau đây gọi là "Nhà thầu" ở một bên)',
      clientSide: '(sau đây gọi là "Khách hàng" ở bên kia)',
      contractAgreement: 'ký kết hợp đồng dịch vụ.',
      
      // Client details
      clientLabel: 'Khách hàng:',
      venueLabel: 'Địa điểm:',
      dateLabel: 'Ngày:',
      phoneLabel: 'Điện thoại:',
      emailLabel: 'Email:',
      
      // Contract sections
      generalTerms: 'ĐIỀU KHOẢN VÀ ĐIỀU KIỆN CHUNG',
      generalTermsText1: 'Điều khoản và Điều kiện Chung (sau đây gọi là "GTC") áp dụng cho tất cả hợp đồng dịch vụ sản xuất video, dịch vụ video và xác nhận đơn hàng của doanh nhân Bui Van Yen, có địa chỉ đăng ký Libušská 319/126, 14200 Prague, Mã số doanh nghiệp: 28578996 (sau đây gọi là "nhà thầu")',
      generalTermsText2: 'Khi ký kết hợp đồng, giả định rằng khách hàng đã quen thuộc với các GTC này và các tài liệu khác được mô tả dưới đây.',
      
      pricingTerms: 'GIÁ CHỦ ĐỀ, THỜI GIAN HIỆU LỰC GIÁ VÀ PHƯƠNG THỨC THANH TOÁN',
      pricingText1: 'Các bên hợp đồng đã thỏa thuận rằng tổng giá của công việc sẽ là',
      pricingText2: 'và sẽ được thanh toán vào tài khoản ngân hàng nói trên như sau:',
      pricingText3: '1. Phí đặt chỗ (Tiền cọc) 40% tổng số tiền sau khi ký hợp đồng',
      pricingText4: '2. Thanh toán số dư theo thỏa thuận (trước hoặc sau tiệc cưới bằng tiền mặt, hoặc 1-3 ngày sau tiệc cưới vào tài khoản ngân hàng nói trên.',
      pricingText5: 'Phí đặt chỗ (tiền cọc) không được hoàn lại.',
      
      cancellationTerms: 'ĐIỀU KIỆN HỦY HỢP ĐỒNG',
      cancellationText1: 'Nếu Khách hàng tự ý hủy hoặc chấm dứt hợp đồng vì bất kỳ lý do nào - chẳng hạn như thay đổi quay phim hoặc thay đổi ngày khi người quay phim không thể thỏa thuận về lịch trình, Khách hàng sẽ mất tiền cọc.',
      cancellationText2: 'Nếu việc hủy là vì lý do chấp nhận được, tiền cọc sẽ được dành riêng cho ngày thỏa thuận khác hoặc người khác (có thể chuyển cho bạn bè, thành viên gia đình, v.v. - hiệu lực 1 năm)',
      
      contractorRights: 'QUYỀN VÀ NGHĨA VỤ CỦA NHÀ THẦU',
      contractorText1: 'Trừ khi có thỏa thuận khác, nhà thầu sẽ thực hiện công việc với chất lượng thông thường ở Cộng hòa Séc và giao:',
      contractorText2: 'Các bên hợp đồng đã thỏa thuận rằng công việc sẽ được hoàn thành và giao bởi Nhà thầu trong vòng',
      contractorText3: 'từ ngày tiệc cưới. Thời gian xử lý video có thể được kéo dài, khách hàng sẽ được thông báo.',
      contractorText4: 'Bằng thỏa thuận với khách hàng, nhà thầu có quyền sử dụng video đã chỉnh sửa cho bản trình bày web của họ (mạng xã hội - FB, IG và các mạng khác) hoặc vật liệu in như mẫu công việc của họ, hoặc cho mục đích quảng cáo dịch vụ của họ.',
      contractorText5: 'Nhà thầu cam kết hoàn thành và giao công việc được đặt hàng với số lượng và chất lượng thỏa thuận trong hợp đồng này.',
      contractorText6: 'Sản phẩm hoàn thiện sẽ được lưu trữ cho Khách hàng trong 1 năm. Trong trường hợp mất, khách hàng có thể yêu cầu trả lại. Sau 1 năm, Nhà thầu không chịu trách nhiệm về sản phẩm (sẽ tính phí USB + bưu phí).',
      
      clientRights: 'QUYỀN VÀ NGHĨA VỤ CỦA KHÁCH HÀNG',
      clientText1: 'Khách hàng có quyền yêu cầu nhà thầu xóa video khỏi mạng xã hội trong trường hợp khách hàng từ chối chúng vì lý do cá nhân. Nhà thầu cam kết tuân thủ yêu cầu đó càng sớm càng tốt sau khi nhận được yêu cầu.',
      clientText2: 'Khách hàng có thể thay đổi ngày của họ do thời tiết hoặc lý do cá nhân, nếu Nhà thầu có sẵn vào ngày mới.',
      clientText3: 'Khách hàng có quyền yêu cầu nhà thầu chỉnh sửa video 1-3 lần',
      clientSpecialRequirements: 'Yêu cầu đặc biệt của khách hàng:',
      
      changesExceptions: '*THAY ĐỔI VÀ NGOẠI LỆ',
      changesText: 'Khách hàng có quyền trong trường hợp bất khả kháng (đặc biệt là lệnh từ các cơ quan quản lý công cộng Séc hạn chế việc tiến hành ngày cưới) chuyển ngày sự kiện sang ngày mới trong cùng năm mà không mất phí.',
      
      // Package info
      packageLabel: 'Gói:',
      workingHours: 'Giờ làm việc:',
      deliverables: 'Sản phẩm giao:',
      
      // Signature section
      signatureSection: 'CHỮ KÝ',
      contractorSignature: 'Chữ ký nhà thầu:',
      clientSignature: 'Chữ ký khách hàng:',
      date: 'Ngày:',
      signedBy: 'Được ký bởi:',
      signatureDate: 'Ngày ký:',
      signContract: 'Ký hợp đồng',
      confirmSignature: 'Xác nhận chữ ký',
      signatureConfirmation: 'Xác nhận rằng bạn muốn ký hợp đồng.',
      signatureSuccess: 'Hợp đồng đã được ký thành công',
      signatureError: 'Không thể ký hợp đồng. Vui lòng thử lại.',
      
      // Amendment section
      amendments: 'PHỤ LỤC HỢP ĐỒNG',
      
      // Toast messages
      toastError: 'Lỗi',
      toastSuccess: 'Thành công',
      toastLinkCopied: 'Liên kết đã được sao chép vào clipboard',
      toastDataLoadError: 'Không thể tải dữ liệu hợp đồng',
      
      // Payment status
      totalAmount: 'Tổng số tiền',
      paidDeposit: 'Tiền cọc đã trả',
      remainingPayment: 'Thanh toán còn lại',
      paymentDue: 'Ngày thanh toán',
      
      // Wedding info
      venue: 'Địa điểm',
      address: 'Địa chỉ',
      requirements: 'Yêu cầu đặc biệt',
      gifts: 'Quà tặng kèm theo',
      delivery: 'Thời gian giao hàng'
    },
    
    // Common
    common: {
      loading: 'Đang tải...',
      error: 'Lỗi',
      success: 'Thành công',
      yes: 'Có',
      no: 'Không',
      close: 'Đóng',
      back: 'Quay lại'
    }
  }
};

// DATABASE-BASED TRANSLATION FUNCTION
export const getContractTranslations = async (contractLanguage: string) => {
  console.log('🔍 getContractTranslations called with language:', contractLanguage);
  
  // Ultra-aggressive cache busting for production deployments
  const cacheBuster = Date.now();
  const sessionId = Math.random().toString(36).substring(2, 15);
  const isProduction = typeof window !== 'undefined' && window.location.hostname !== 'localhost';
  
  console.log('🎯 Cache buster timestamp:', cacheBuster);
  console.log('🎯 Session ID:', sessionId);
  console.log('🎯 Is production:', isProduction);
  
  const language = contractLanguage?.toString().trim().toUpperCase();
  console.log('🎯 Normalized language:', language);
  console.log('🎯 Language type:', typeof language);
  console.log('🎯 Language length:', language?.length);
  
  try {
    // Fetch translations from database - this bypasses ALL caching!
    console.log('🔄 Fetching translations from database...');
    const { data: translationData, error } = await supabase
      .rpc('get_translations_for_language', { lang_code: language });
    
    if (error) {
      console.error('❌ Error fetching translations:', error);
      console.log('🔄 Falling back to static translations');
      return getFallbackTranslations(language);
    }
    
    if (!translationData || translationData.length === 0) {
      console.warn('⚠️ No translations found for language:', language);
      console.log('🔄 Falling back to static translations');
      
      // Log available translations for debugging
      try {
        const { data: allTranslations } = await supabase
          .from('translations')
          .select('language_code, section, key')
          .limit(10);
        console.log('📋 Available translations sample:', allTranslations);
      } catch (debugError) {
        console.log('🔍 Could not fetch debug translations:', debugError);
      }
      
      return getFallbackTranslations(language);
    }
    
    console.log('✅ Successfully fetched', translationData.length, 'translations from database');
    
    // Build nested translation object from flat database structure
    const translations = buildTranslationObject(translationData);
    
    console.log('🎯 Database translations built:', translations);
    console.log('🎯 Contract title from database:', translations.publicContract?.contractTitle);
    
    // In production, add extra verification
    if (isProduction) {
      console.log('🚨 PRODUCTION - Contract Language:', contractLanguage);
      console.log('🚨 PRODUCTION - Database Translation Title:', translations.publicContract?.contractTitle);
      console.log('🚨 PRODUCTION - Database Translation Company:', translations.publicContract?.companyName);
    }
    
    return translations;
    
  } catch (error) {
    console.error('❌ Error in getContractTranslations:', error);
    console.log('🔄 Falling back to static translations');
    return getFallbackTranslations(language);
  }
};

// Helper function to build nested object from flat database structure
function buildTranslationObject(translationData: any[]): any {
  const result: any = {};
  
  translationData.forEach(item => {
    const { section, key, value } = item;
    
    if (!result[section]) {
      result[section] = {};
    }
    
    // Handle nested keys (e.g., "nav.home" -> result.nav.home)
    const keyParts = key.split('.');
    let current = result[section];
    
    for (let i = 0; i < keyParts.length - 1; i++) {
      const part = keyParts[i];
      if (!current[part]) {
        current[part] = {};
      }
      current = current[part];
    }
    
    current[keyParts[keyParts.length - 1]] = value;
  });
  
  return result;
}

// Fallback function using static translations
function getFallbackTranslations(language: string) {
  console.log('🔄 Using fallback static translations for:', language);
  
  // Force fresh translation object creation to bypass any caching
  const sourceTranslations = contractTranslations[language as keyof typeof contractTranslations] || contractTranslations.EN;
  
  // Create a completely new object to bypass any potential caching
  const translations = JSON.parse(JSON.stringify(sourceTranslations));
  
  console.log('🎯 Fallback translations:', translations);
  console.log('🎯 Fallback contract title:', translations.publicContract?.contractTitle);
  
  return translations;
}

export const translations: Record<Language, Translations> = {
  EN: {
    header: {
      bookConsultation: 'Book Free Consultation',
      navigation: {
        home: 'Home',
        portfolio: 'Portfolio',
        packages: 'Packages',
        testimonials: 'Testimonials',
        about: 'About Us',
        contact: 'Contact',
      },
    },
    hero: {
      title: 'SOMETHING DIFFERENT,',
      subtitle: 'SOMETHING PERSONAL',
      description: 'A unique approach that focuses on maximizing the time you spend with your guests and ensuring you feel fully seen as a couple while immortalizing the vibe and making it a forever memory.',
      cta: "Let's Connect",
    },
    about: {
      title: 'Capturing Love Stories',
      philosophy: 'Our Philosophy',
      description: 'A fulfilling wedding is not just the result of love — it\'s the beginning of a new chapter where affection deepens and responsibility grows. At Tuan Master, we carry the mission of preserving and narrating the emotional essence of your most important day. We believe that every love story, when told through a cinematic lens, has the power to become a timeless, authentic, and deeply moving film.\n\nBuilt on the passion of a team of young creatives who truly believe in love, Tuan Master is more than just a wedding videography crew — we are devoted storytellers. With every project, we see it as a great honor to be entrusted with capturing a pivotal moment in your life, and we give it our heart, soul, and artistry. Your story is one of a kind, and we\'re here to turn it into a film you\'ll cherish forever.',
    },
    services: {
      title: 'Investment in Your',
      subtitle: 'Love Story',
      description: 'Thoughtfully crafted packages to preserve every precious moment of your celebration',
      mostPopular: 'MOST POPULAR',
      singleVideographer: 'SINGLE VIDEOGRAPHER',
      dualVideographers: 'DUAL VIDEOGRAPHERS',
      discoverLuxury: 'Discover Luxury',
      limitedBonus: 'Limited Time Bonus',
      bonusTitle: 'Social Media REELS Package',
      bonusDescription: 'We\'ll create 1-3 trending 10-30 second videos crafted specifically for Instagram & TikTok. These professionally edited highlight reels will help your love story go viral and create unforgettable moments you can share with friends and family on social media.',
      bonusNote: 'Perfect for maximizing your social media impact and sharing your special day',
      bottomNote: 'All packages include professional editing, color grading, and lifetime cloud storage',
      beyond: 'Beyond Extraordinary',
      beyondSubtitle: 'For couples who desire nothing but the finest',
      chooseEssential: 'Choose Essential',
      choosePremium: 'Choose Premium',
      essential: {
        name: 'Essential',
        title: '6 Hours Coverage',
        description: 'Perfect for intimate ceremonies',
        workingHours: '6 hours working time',
        overtimeNote: 'Overtime: €60/hour (1 videographer) or €120/hour (2 videographers)',
      },
      premium: {
        name: 'Premium',
        title: '8 Hours Coverage',
        description: 'Most couples\' favorite choice',
        workingHours: '8 hours working time',
        overtimeNote: 'Overtime: €60/hour (1 videographer) or €120/hour (2 videographers)',
      },
      luxury: {
        name: 'Luxury Experience',
        title: 'Full Day Premium Coverage',
        description: 'For couples who desire the extraordinary',
        workingHours: 'Full day coverage',
        timeRange: 'Working hours: 10:00 AM - 10:30 PM',
      },
      features: {
        highlightReel: '3-5 minute highlight reel',
        fullCeremonyFilm: '7-15 minute full ceremony film',
        usbPackage: 'Branded USB package',
        musicSoundtrack: 'Licensed music soundtrack',
        consultation: 'Pre-wedding consultation',
        extendedCoverage: 'Extended reception coverage',
        sneakPeek: 'Same-day sneak peek',
        cinematicHighlight: '3-5 minute cinematic highlight reel',
        premiumUsb: 'Premium branded USB package',
        extensiveConsultation: 'Extensive pre-wedding consultation',
        fullDayCoverage: 'Full day coverage (12+ hours)',
        socialTeasers: 'Optional social media teasers',
        premiumEditing: 'Premium editing package',
        droneFootage: 'Drone footage (weather permitting)',
        secondShooter: 'Second shooter included',
        rawFootage: 'Raw footage access',
        prioritySupport: 'Priority customer support',
      },
    },
    contact: {
      title: 'Say hello',
      subtitle: "Let's work together",
      basedIn: 'Based in Prague, Czech Republic',
      travelNote: 'Our team is able to travel and provide services across Europe',
      form: {
        yourName: 'Your name *',
        partnerName: "Partner's name",
        sessionType: 'Type of session *',
        chooseSessionType: 'Choose session type',
        dateLabel: 'Date of Wedding/Session *',
        pickDate: 'Pick a date',
        email: 'Email address *',
        phone: 'Phone Number *',
        location: 'Wedding/Session Location *',
        message: 'Message *',
        messagePlaceholder: 'Tell us about your special day...',
        sendMessage: 'Send Message',
        sessionTypes: {
          wedding: 'Wedding',
          engagement: 'Engagement',
          portrait: 'Portrait',
          family: 'Family',
          elopement: 'Elopement',
          rehearsal: 'Rehearsal',
          ceremony: 'Ceremony',
        },
      },
    },
    testimonials: {
      title: 'Testimonials',
    },
    partners: {
      title: 'PARTNERS',
      subtitle: 'WEDDING SERVICES',
      description: 'Tuan Master\'s partners are all professional units in the wedding service industry. With many years of experience and deep understanding of customer needs, we believe that the exceptional services and benefits from our partners will help every bride and groom achieve their perfect and complete wedding celebration.',
    },
    offerings: {
      title: 'THE OFFERINGS',
      services: {
        wedding: 'Capturing the magic of your special day with timeless elegance and authentic emotion.',
        portraits: 'Creating intimate portraits that reveal the unique beauty and personality of each subject.',
        editorial: 'Fashion and lifestyle photography with artistic vision and professional precision.',
        brands: 'Visual storytelling that elevates your brand through compelling and cohesive imagery.',
      },
    },
    footer: {
      explore: 'EXPLORE',
      learn: 'LEARN',
      connect: 'CONNECT',
      stories: 'STORIES',
      albums: 'ALBUMS',
      venues: 'VENUES',
      faq: 'FAQ',
      tips: 'TIPS',
      pricing: 'PRICING',
      contact: 'CONTACT',
      about: 'ABOUT',
      socialMedia: 'INSTAGRAM / TIKTOK / FACEBOOK',
      copyright: '© 2025 Tuan Master Studio. All rights reserved.',
    },
    instagram: {
      scrollText: 'FIND ME ON TIKTOK / RESERVE YOUR DATE / FOLLOW ALONG ON INSTAGRAM / RESERVE YOUR DATE / FOLLOW ALONG ON INSTAGRAM / RESERVE YOUR DATE / FOLLOW ALONG ON INSTAGRAM / RESERVE YOUR DATE / FOLLOW ALONG ON INSTAGRAM',
    },
    blog: {
      viewAllStories: 'View All Stories',
    },
    common: {
      prague: 'Prague',
      czechRepublic: 'Czech Republic',
    },
  },
  CZ: {
    header: {
      bookConsultation: 'Domluvit si schůzku',
      navigation: {
        home: 'Úvod',
        portfolio: 'Naše práce',
        packages: 'Balíčky',
        testimonials: 'Co říkají naši klienti',
        about: 'Náš příběh',
        contact: 'Napište nám',
      },
    },
    hero: {
      title: 'VÁŠ PŘÍBĚH,',
      subtitle: 'NAŠE VÁŠEŇ',
      description: 'Věříme, že každá svatba je jedinečná. Proto se soustředíme na to, co je pro vás opravdu důležité - abyste si svůj den užili naplno, zatímco my zachytíme každý úsměv, každé objetí, každou slzu štěstí.',
      cta: 'Začněme spolu',
    },
    about: {
      title: 'Tvoříme vzpomínky na celý život',
      philosophy: 'Proč děláme to, co děláme',
      description: 'Svatba není jen oslava lásky - je to začátek nového příběhu. My v Tuan Master víme, jak cenné jsou tyto okamžiky. Proto každý natáčený snímek prožíváme s vámi, každý úsměv zachycujeme s láskou a každý příběh vyprávíme s respektem k tomu, co pro vás znamená.\n\nJsme tým mladých lidí, kteří milují příběhy a věří v sílu lásky. Nejsme jen kameramani - jsme vaši přátelé, kteří chtějí, aby vaše vzpomínky zůstaly krásné navždycky. Když nám svěříte svůj nejdůležitější den, bereme to jako velkou zodpovědnost a čest.',
    },
    services: {
      title: 'Každý příběh si zaslouží',
      subtitle: 'být vyprávěn krásně',
      description: 'Balíčky šité na míru vašim přáním, aby žádný důležitý okamžik neunikl',
      mostPopular: 'NEJČASTĚJŠÍ VOLBA',
      singleVideographer: 'JEDEN KAMERAMAN',
      dualVideographers: 'DUO KAMERAMANŮ',
      discoverLuxury: 'Poznat luxusní zážitek',
      limitedBonus: 'Speciální dárek zdarma',
      bonusTitle: 'REELS pro sociální sítě',
      bonusDescription: 'Vytvoříme vám 1-3 krátká videa speciálně pro Instagram a TikTok. Krásné sestřihy, které můžete hned sdílet s přáteli a ukázat všem, jak úžasný den jste měli.',
      bonusNote: 'Ideální způsob, jak se pochlubit svým velkým dnem na sociálních sítích',
      bottomNote: 'Každý balíček obsahuje profesionální zpracování a bezpečné uložení na celý život',
      beyond: 'Když chcete úplně všechno',
      beyondSubtitle: 'Pro páry, kterým jde o dokonalost',
      chooseEssential: 'Chci Essential',
      choosePremium: 'Chci Premium',
      essential: {
        name: 'Essential',
        title: 'Šest hodin s vámi',
        description: 'Pro intimní svatby a menší oslavy',
        workingHours: 'Pracovní doba: 6 hodin',
        overtimeNote: 'Přesčas: 1500 Kč/hod (1 kameraman) nebo 3000 Kč/hod (2 kameramani)',
      },
      premium: {
        name: 'Premium',
        title: 'Osm hodin plných emocí',
        description: 'Nejvíc si vybírají páry jako vy',
        workingHours: 'Pracovní doba: 8 hodin',
        overtimeNote: 'Přesčas: 1500 Kč/hod (1 kameraman) nebo 3000 Kč/hod (2 kameramani)',
      },
      luxury: {
        name: 'Luxury Experience',
        title: 'Celý den v našich rukách',
        description: 'Když nechcete nechat nic náhodě',
        workingHours: 'Celodenní pokrytí',
        timeRange: 'Pracovní doba: 10:00 - 22:30',
      },
      features: {
        highlightReel: 'Krásný sestřih 3-5 minut',
        fullCeremonyFilm: 'Celý obřad 7-15 minut',
        usbPackage: 'Hezké USB s logem',
        musicSoundtrack: 'Licencovaná hudba',
        consultation: 'Povídání před svatbou',
        extendedCoverage: 'Natáčíme i hostinu',
        sneakPeek: 'Ukázka ještě ten den',
        cinematicHighlight: 'Filmový sestřih 3-5 minut',
        premiumUsb: 'Luxusní USB s logem',
        extensiveConsultation: 'Dlouhé povídání před svatbou',
        fullDayCoverage: 'Celý den s vámi (12+ hodin)',
        socialTeasers: 'Krátká videa na sítě',
        premiumEditing: 'Nejlepší zpracování',
        droneFootage: 'Záběry z dronu (pokud bude počasí)',
        secondShooter: 'Dva kameramani',
        rawFootage: 'Všechny záběry navíc',
        prioritySupport: 'Nejrychlejší odpovědi',
      },
    },
    contact: {
      title: 'Napište nám',
      subtitle: 'Rádi se s vámi seznámíme',
      basedIn: 'Jsme z Prahy, ale rádi se vydáme kamkoliv',
      travelNote: 'Natáčíme po celé Evropě - vaše místo, náš příběh',
      form: {
        yourName: 'Jak se jmenujete? *',
        partnerName: 'A váš partner?',
        sessionType: 'O co máte zájem? *',
        chooseSessionType: 'Vyberte z nabídky',
        dateLabel: 'Kdy to bude? *',
        pickDate: 'Vyberte datum',
        email: 'Váš email *',
        phone: 'Telefon *',
        location: 'Kde to bude? *',
        message: 'Vaše zpráva *',
        messagePlaceholder: 'Povíme si o vašem velkém dni a o tom, co si představujete...',
        sendMessage: 'Odeslat',
        sessionTypes: {
          wedding: 'Svatba',
          engagement: 'Zásnuby',
          portrait: 'Portrét',
          family: 'Rodinné',
          elopement: 'Útěk',
          rehearsal: 'Zkouška',
          ceremony: 'Ceremonie',
        },
      },
    },
    testimonials: {
      title: 'Reference',
    },
    partners: {
      title: 'PARTNEŘI',
      subtitle: 'SVATEBNÍ SLUŽBY',
      description: 'Partneři Tuan Master jsou všechno profesionální jednotky ve svatebním průmyslu. S mnohaletými zkušenostmi a hlubokým porozuměním potřebám zákazníků věříme, že výjimečné služby a výhody od našich partnerů pomohou každému páru dosáhnout jejich dokonalé a úplné svatební oslavy.',
    },
    offerings: {
      title: 'NAŠE NABÍDKA',
      services: {
        wedding: 'Zachycujeme kouzlo vašeho velkého dne s nadčasovou elegancí a autentickými emocemi.',
        portraits: 'Vytváříme intimní portréty, které odhalují jedinečnou krásu a osobnost každého člověka.',
        editorial: 'Módní a lifestyle fotografie s uměleckým viděním a profesionální precizností.',
        brands: 'Vizuální vyprávění, které pozdvihuje vaši značku prostřednictvím přesvědčivých a soudržných obrazů.',
      },
    },
    footer: {
      explore: 'PROZKOUMAT',
      learn: 'UČIT SE',
      connect: 'SPOJIT SE',
      stories: 'PŘÍBĚHY',
      albums: 'ALBA',
      venues: 'MÍSTA',
      faq: 'FAQ',
      tips: 'TIPY',
      pricing: 'CENY',
      contact: 'KONTAKT',
      about: 'O NÁS',
      socialMedia: 'INSTAGRAM / TIKTOK / FACEBOOK',
      copyright: '© 2025 Tuan Master Studio. Všechna práva vyhrazena.',
    },
    instagram: {
      scrollText: 'NAJDĚTE MĚ NA TIKTOKU / REZERVUJTE SI DATUM / SLEDUJTE MĚ NA INSTAGRAMU / REZERVUJTE SI DATUM / SLEDUJTE MĚ NA INSTAGRAMU / REZERVUJTE SI DATUM / SLEDUJTE MĚ NA INSTAGRAMU / REZERVUJTE SI DATUM / SLEDUJTE MĚ NA INSTAGRAMU',
    },
    blog: {
      viewAllStories: 'Zobrazit všechny příběhy',
    },
    common: {
      prague: 'Praha',
      czechRepublic: 'Česká republika',
    },
  },
  VI: {
    header: {
      bookConsultation: 'Hẹn gặp chúng mình',
      navigation: {
        home: 'Về nhà',
        portfolio: 'Những câu chuyện',
        packages: 'Gói quay phim',
        testimonials: 'Tâm sự khách hàng',
        about: 'Câu chuyện của mình',
        contact: 'Nói chuyện cùng mình',
      },
    },
    hero: {
      title: 'TÌNH YÊU CỦA BẠN,',
      subtitle: 'ĐAM MÊ CỦA CHÚNG MÌNH',
      description: 'Mỗi đám cưới đều có nét riêng. Chúng mình hiểu điều đó và luôn chú tâm vào những gì quan trọng nhất - để bạn tận hưởng từng phút giây hạnh phúc, trong khi chúng mình ghi lại từng nụ cười, từng cái ôm, từng giọt nước mắt hạnh phúc.',
      cta: 'Bắt đầu cùng nhau',
    },
    about: {
      title: 'Chúng mình làm phim về tình yêu',
      philosophy: 'Tại sao chúng mình làm việc này',
      description: 'Đám cưới không chỉ là lễ cưới - đó là khởi đầu của một hành trình mới. Ở Tuan Master, chúng mình hiểu rõ những khoảnh khắc này quý giá như thế nào. Vì thế, mỗi thước phim chúng mình quay đều chứa đầy tình cảm, mỗi khoảnh khắc đều được ghi lại với tất cả tâm huyết.\n\nChúng mình là nhóm bạn trẻ yêu thích kể chuyện và tin vào sức mạnh của tình yêu. Không chỉ đơn thuần là thợ quay phim, chúng mình còn là người bạn muốn giúp bạn lưu giữ những kỷ niệm đẹp nhất. Khi bạn tin tưởng giao phó ngày trọng đại cho chúng mình, đó là niềm vinh hạnh và trách nhiệm lớn lao.',
    },
    services: {
      title: 'Mỗi tình yêu đều xứng đáng',
      subtitle: 'có một bộ phim riêng',
      description: 'Những gói quay phim được thiết kế riêng để không bỏ lỡ bất kỳ khoảnh khắc đẹp nào',
      mostPopular: 'LỰA CHỌN PHỔ BIẾN',
      singleVideographer: 'MỘT QUAY PHIM',
      dualVideographers: 'HAI QUAY PHIM',
      discoverLuxury: 'Khám phá gói đỉnh cao',
      limitedBonus: 'Quà tặng đặc biệt',
      bonusTitle: 'Video ngắn cho mạng xã hội',
      bonusDescription: 'Chúng mình sẽ làm thêm 1-3 video ngắn xinh xắn cho Instagram và TikTok. Những clip đẹp mắt để bạn khoe với bạn bè về ngày hạnh phúc nhất đời mình.',
      bonusNote: 'Cách tuyệt vời để chia sẻ niềm vui với mọi người trên mạng xã hội',
      bottomNote: 'Tất cả gói đều bao gồm chỉnh sửa chuyên nghiệp và lưu trữ an toàn suốt đời',
      beyond: 'BEYOND AND ABOVE',
      beyondSubtitle: 'Dành cho những ai tìm kiếm sự đẳng cấp và hoàn hảo nhất',
      chooseEssential: 'Chọn gói Essential',
      choosePremium: 'Chọn gói Premium',
      essential: {
        name: 'Essential',
        title: 'Sáu tiếng cùng bạn',
        description: 'Phù hợp với tiệc cưới ấm cúng',
        workingHours: 'Thời gian làm việc: 6 tiếng',
        overtimeNote: 'Thêm giờ: 1500 Kč/giờ (1 quay phim) hoặc 3000 Kč/giờ (2 quay phim)',
      },
      premium: {
        name: 'Premium',
        title: 'Tám tiếng đầy cảm xúc',
        description: 'Lựa chọn được yêu thích nhất',
        workingHours: 'Thời gian làm việc: 8 tiếng',
        overtimeNote: 'Thêm giờ: 1500 Kč/giờ (1 quay phim) hoặc 3000 Kč/giờ (2 quay phim)',
      },
      luxury: {
        name: 'Luxury Experience',
        title: 'Bắt trọn mọi cảm xúc trong thời gian 1 ngày',
        description: 'Khi bạn muốn mọi thứ hoàn hảo',
        workingHours: 'Thời gian làm việc: Full Time',
        timeRange: 'Làm việc từ 10:00 - 22:30',
      },
      features: {
        highlightReel: 'Clip tóm tắt 3-5 phút',
        fullCeremonyFilm: 'Video lễ cưới hoàn chỉnh 7-15 phút',
        usbPackage: 'USB sang trọng',
        musicSoundtrack: 'Nhạc nền bản quyền',
        consultation: 'Tư vấn trước cưới',
        extendedCoverage: 'Quay thêm tiệc cưới',
        sneakPeek: 'Xem ngay trong ngày',
        cinematicHighlight: 'Clip đậm chất điện ảnh 3-5 phút',
        premiumUsb: 'USB đẳng cấp in kèm tên bạn',
        extensiveConsultation: 'Tư vấn chi tiết trước cưới',
        fullDayCoverage: 'Quay cả ngày (12+ tiếng)',
        socialTeasers: 'Video ngắn cho mạng xã hội',
        premiumEditing: 'Chỉnh sửa cao cấp',
        droneFootage: 'Quay drone (tùy thời tiết)',
        secondShooter: 'Thêm một quay phim',
        rawFootage: 'Video gốc chưa chỉnh sửa',
        prioritySupport: 'Hỗ trợ ưu tiên',
      },
    },
    contact: {
      title: 'Chào bạn!',
      subtitle: 'Kể cho chúng mình nghe về tình yêu của bạn',
      basedIn: 'Chúng mình ở Prague, nhưng sẵn sàng đi bất cứ đâu',
      travelNote: 'Khắp châu Âu - nơi nào có tình yêu, nơi đó có chúng mình',
      form: {
        yourName: 'Bạn tên gì? *',
        partnerName: 'Tên nửa kia của bạn?',
        sessionType: 'Bạn cần dịch vụ gì nhỉ? *',
        chooseSessionType: 'Chọn loại quay phim',
        dateLabel: 'Thời gian diễn ra? *',
        pickDate: 'Chọn ngày',
        email: 'Email của bạn *',
        phone: 'Số điện thoại *',
        location: 'Bạn đang ở đâu? *',
        message: 'Kể cho chúng mình nghe *',
        messagePlaceholder: 'Kể về ngày đặc biệt của bạn và những gì bạn mong muốn...',
        sendMessage: 'Gửi thông tin',
        sessionTypes: {
          wedding: 'Đám cưới',
          engagement: 'Lễ đính hôn',
          portrait: 'Chụp hình đôi',
          family: 'Gia đình',
          elopement: 'Cưới riêng tư',
          rehearsal: 'Tập dượt',
          ceremony: 'Lễ cưới',
        },
      },
    },
    testimonials: {
      title: 'Đánh giá',
    },
    partners: {
      title: 'ĐỐI TÁC',
      subtitle: 'DỊCH VỤ CƯỚI',
      description: 'Tất cả đối tác của Tuan Master đều là những đơn vị chuyên nghiệp trong lĩnh vực dịch vụ cưới. Với kinh nghiệm nhiều năm và sự hiểu biết sâu sắc về nhu cầu của khách hàng, chúng tôi tin tưởng rằng những dịch vụ xuất sắc và các ưu đãi từ đối tác sẽ giúp mỗi cặp đôi có được một đám cưới hoàn hảo và trọn vẹn nhất.',
    },
    offerings: {
      title: 'DỊCH VỤ CỦA CHÚNG MÌNH',
      services: {
        wedding: 'Ghi lại những khoảnh khắc kỳ diệu trong ngày đặc biệt của bạn với sự tao nhã vượt thời gian và cảm xúc chân thật.',
        portraits: 'Tạo ra những bức chân dung thân mật, khám phá vẻ đẹp và cá tính độc đáo của từng con người.',
        editorial: 'Chụp ảnh thời trang và phong cách sống với tầm nhìn nghệ thuật và độ chính xác chuyên nghiệp.',
        brands: 'Kể chuyện bằng hình ảnh, nâng tầm thương hiệu của bạn thông qua những hình ảnh hấp dẫn và nhất quán.',
      },
    },
    footer: {
      explore: 'KHÁM PHÁ',
      learn: 'TÌM HIỂU THÊM',
      connect: 'KẾT NỐI',
      stories: 'CÂU CHUYỆN',
      albums: 'ALBUM',
      venues: 'ĐỊA ĐIỂM',
      faq: 'FAQ',
      tips: 'MẸO',
      pricing: 'GIÁ CẢ',
      contact: 'LIÊN HỆ',
      about: 'VỀ CHÚNG TÔI',
      socialMedia: 'INSTAGRAM / TIKTOK / FACEBOOK',
      copyright: '© 2025 Tuan Master Studio. Tất cả quyền được bảo lưu.',
    },
    instagram: {
      scrollText: 'TÌM TÔI TRÊN TIKTOK / ĐẶT LỊCH NGAY / THEO DÕI TRÊN INSTAGRAM / ĐẶT LỊCH NGAY / THEO DÕI TRÊN INSTAGRAM / ĐẶT LỊCH NGAY / THEO DÕI TRÊN INSTAGRAM / ĐẶT LỊCH NGAY / THEO DÕI TRÊN INSTAGRAM',
    },
    blog: {
      viewAllStories: 'Xem tất cả câu chuyện',
    },
    common: {
      prague: 'Prague',
      czechRepublic: 'Cộng hòa Séc',
    },
  },
}; 